@@ -244,6 +244,7 @@ function add(opt) {
             }
 
             // if label, format, color, units, tooltip or icon fields are set to a msg property, emit that as well
+            addField("className");
             addField("label");
             addField("format");
             addField("color");
@@ -251,6 +252,7 @@ function add(opt) {
             addField("tooltip");
             addField("icon");
             if (msg.hasOwnProperty("enabled")) { toEmit.disabled = !msg.enabled; }
+            if (msg.hasOwnProperty("className")) { toEmit.className = msg.className; }
             toEmit.id = toStore.id = opt.node.id;
             //toEmit.socketid = msg.socketid; // dcj mu
             // Emit and Store the data
@@ -553,13 +555,14 @@ function addControl(tab, groupHeader, control) {
     }
 }
 
-function addLink(name, link, icon, order, target) {
+function addLink(name, link, icon, order, target, className) {
     var newLink = {
         name: name,
         link: link,
         icon: icon,
         order: order || 1,
-        target: target
+        target: target,
+        className: className
     };
 
     menu.push(newLink);
